@@ -30,10 +30,6 @@
 
 from .plugins import *
 
-from .network import ServiceProvider, Station, Robot
-
-from .group import Polylogue, Chatroom, ChatroomDataSource
-
 from .protocol import ReceiptCommand, HandshakeCommand, LoginCommand
 from .protocol import BlockCommand, MuteCommand, StorageCommand
 
@@ -44,13 +40,18 @@ from .cpu import ResetCommandProcessor, QueryCommandProcessor
 from .cpu import MetaCommandProcessor, DocumentCommandProcessor
 from .cpu import ProcessorFactory
 
+from .network import ServiceProvider, Station, Robot
+from .group import Polylogue, Chatroom, ChatroomDataSource
+
+from .ans import AddressNameService
+from .delegate import CipherKeyDelegate
+from .transmitter import Transmitter
+
 from .facebook import Facebook
 from .packer import MessagePacker
 from .processor import MessageProcessor
 from .messenger import Messenger
 
-from .ans import AddressNameService
-
 name = 'DIM-SDK'
 
 __author__ = 'Albert Moky'
@@ -74,8 +75,7 @@ __all__ = [
     #   Content/Command Processors
     #
     'ContentProcessor', 'ForwardContentProcessor',
-    'CommandProcessor', 'HistoryCommandProcessor',
-    'GroupCommandProcessor',
+    'CommandProcessor', 'HistoryCommandProcessor', 'GroupCommandProcessor',
     'InviteCommandProcessor', 'ExpelCommandProcessor', 'QuitCommandProcessor',
     'ResetCommandProcessor', 'QueryCommandProcessor',
     'MetaCommandProcessor', 'DocumentCommandProcessor',
@@ -87,6 +87,6 @@ __all__ = [
     # group
     'Polylogue', 'Chatroom', 'ChatroomDataSource',
 
-    'AddressNameService', 'Facebook',
-    'Messenger', 'MessagePacker', 'MessageProcessor',
+    'AddressNameService', 'CipherKeyDelegate', 'Transmitter',
+    'Facebook', 'Messenger', 'MessagePacker', 'MessageProcessor',
 ]
